# -*- coding: utf-8 -*-
# Generated by Django 1.11.17 on 2019-01-03 10:24
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Template",
            fields=[
                ("slug", models.SlugField(primary_key=True, serialize=False)),
                ("description", models.TextField(default="")),
                ("template", models.FileField(max_length=1024, upload_to="")),
                (
                    "engine",
                    models.CharField(
                        choices=[
                            (
                                "docx-template",
                                "Docx Template engine (https://github.com/elapouya/python-docx-template)",
                            ),
                            (
                                "docx-mailmerge",
                                "Docx MailMerge engine (https://github.com/Bouke/docx-mailmerge)",
                            ),
                        ],
                        max_length=20,
                    ),
                ),
            ],
        )
    ]
