# Generated by Django 3.2.16 on 2022-12-23 12:54

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("api", "0005_xlsx_template_engine"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="template",
            name="group",
        ),
    ]
